==> photobiology_0.10.14.tar.gz: photobiology/R/defunct.R <==
#' Defunct functions and methods
#'
#' Functions listed here have been removed or deleted, and temporarily replaced
#' by stubs that report this when they are called.
#'
#' @name defunct
#'
#' @param ... ignored
#'
#' @export
#'
#' @note Function \code{f_mspct()} has been renamed \code{msdply()}.
#'
f_mspct <- function(...) {
  stop("Function 'photobiology::f_mspct()' is defunct, please use 'msdply()' instead.")
}

#' @rdname defunct
#'
#' @export
#'
#' @note Function \code{mutate_mspct()} has been renamed \code{msmsply()}.
#'
mutate_mspct <- function(...) {
  stop("Function 'photobiology::mutate_mspct()' is defunct, please use 'msdply()' instead.")
}

#' @rdname defunct
#'
#' @export
#'
#' @note Function \code{calc_filter_multipliers()} has been removed.
#'
calc_filter_multipliers <- function(...) {
  stop("Function 'photobiology::calc_filter_multipliers()' is defunct, please use
'interpolate_wl()' instead.")
}

#' @rdname defunct
#'
#' @export
#'
#' @note Function \code{calc_filter_multipliers()} has been removed.
#'
T2T <- function(...) {
  stop("Function 'photobiology::T2T()' is defunct, please use
'convertTfrType()' instead.")
}

#' @rdname defunct
#'
#' @export
#'
#' @note Method \code{getAfrType()} has been removed.
#'
getAfrType <- function(...) {
  stop("Function 'photobiology::getAfrType()' is defunct, the \"Afr.type\"
attribute is redundant and no longer used.")
}

#' @rdname defunct
#'
#' @export
#'
#' @note Method \code{setAfrType()} has been removed.
#'
setAfrType <- function(...) {
  stop("Function 'photobiology::setAfrType()' is defunct, the \"Afr.type\"
attribute is redundant and no longer used.")
}

==> photobiology_0.13.0.tar.gz: photobiology/R/defunct.R <==
#' Defunct functions and methods
#'
#' Functions listed here have been removed or deleted, and temporarily replaced
#' by stubs that report this when they are called.
#'
#' @name defunct
#'
#' @param ... ignored
#'
#' @export
#'
#' @note Function \code{f_mspct()} has been renamed \code{msdply()}.
#'
f_mspct <- function(...) {
  stop("Function 'photobiology::f_mspct()' is defunct, please use 'msdply()' instead.")
}

#' @rdname defunct
#'
#' @export
#'
#' @note Function \code{mutate_mspct()} has been renamed \code{msmsply()}.
#'
mutate_mspct <- function(...) {
  stop("Function 'photobiology::mutate_mspct()' is defunct, please use 'msdply()' instead.")
}

#' @rdname defunct
#'
#' @export
#'
#' @note Function \code{calc_filter_multipliers()} has been removed.
#'
calc_filter_multipliers <- function(...) {
  stop("Function 'photobiology::calc_filter_multipliers()' is defunct, please use
'interpolate_wl()' instead.")
}

#' @rdname defunct
#'
#' @export
#'
#' @note Function \code{calc_filter_multipliers()} has been removed.
#'
T2T <- function(...) {
  stop("Function 'photobiology::T2T()' is defunct, please use
'convertTfrType()' instead.")
}

#' @rdname defunct
#'
#' @export
#'
#' @note Method \code{getAfrType()} has been removed.
#'
getAfrType <- function(...) {
  stop("Function 'photobiology::getAfrType()' is defunct, the \"Afr.type\"
attribute is redundant and no longer used.")
}

#' @rdname defunct
#'
#' @export
#'
#' @note Method \code{setAfrType()} has been removed.
#'
setAfrType <- function(...) {
  stop("Function 'photobiology::setAfrType()' is defunct, the \"Afr.type\"
attribute is redundant and no longer used.")
}

#' @rdname defunct
#'
#' @export
#'
#' @note Function \code{sample_spct()} has been removed.
#'
sample_spct <- function(...) {
  stop("Function 'photobiology::sample_spct()' has been replaced by method 'photobiology::pull_sample()'")
}

#' @rdname defunct
#'
#' @export
#'
#' @note Function \code{sample_mspct()} has been removed.
#'
sample_mspct <- function(...) {
  stop("Function 'photobiology::sample_mspct()' has been replaced by method 'photobiology::pull_sample()'")
}
